---
title: Quickstart_cbps
sidebar_position: 3
hide_table_of_contents: true
hide_title: true
---

import HTMLLoader from '@site/src/components/HTMLLoader';
import useBaseUrl from '@docusaurus/useBaseUrl';

Link to notebook: [balance_quickstart_cbps.ipynb](https://github.com/facebookresearch/balance/blob/main/tutorials/balance_quickstart_cbps.ipynb)

<HTMLLoader docFile={useBaseUrl('html/tutorials/balance_quickstart_cbps.html')}/>
